<?php

namespace Controller;

use Exception;
use Traits\TResponse;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Util\Utilities;
use Service\TaskType as TaskTypeService;
use Service\Task as TaskService;

class TaskType extends Simple
{

    use TResponse;

    /**
     * @var TaskTypeService
     */
    private $taskTypeService;
    /**
     * @var TaskService
     */
    private $taskService;

    /**
     * @var \Util\Utilities $utilities
     */
    private $utilities;

    public function __construct(Utilities $utilities, TaskTypeService $taskTypeService, TaskService $taskService)
    {
        $this->utilities = $utilities;
        $this->taskTypeService = $taskTypeService;
        $this->taskService = $taskService;
    }

    public function findTaskType(DTO\Request $request, DTO\Response $response)
    {
        try {
            $data = $this->taskTypeService->findTaskType();
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        try{
            $taskType = $request->getParameters();
            $id = empty($taskType['ID']) ? null : $taskType['ID'];
            $control = $taskType['CONTROL'];
            $label = $taskType['LABEL'];
            $allowCloseIssue = $taskType['ALLOW_CLOSE_ISSUE'];
            $orderToView = filter_var($taskType['ORDER_TO_VIEW'],FILTER_SANITIZE_NUMBER_INT);
            $dayNumbers = empty($taskType['DAY_NUMBERS']) ? null : $taskType['DAY_NUMBERS'];
            $taskClassification = $taskType['TASK_CLASSIFICATION'];
            $allowPlayTask = $taskType['ALLOW_PLAY_TASK'];
            $issueClassification = $taskType['ISSUE_CLASSIFICATION'];
            $comment = empty($taskType['DESCRIPTION']) ? null : $taskType['DESCRIPTION'];
            $targetStatus = empty($taskType['TARGET_STATUS']) ? null : $taskType['TARGET_STATUS'];
            $this->taskService->updateTaskType($id, $control, $label, $allowCloseIssue,$orderToView,$dayNumbers,
                $taskClassification, $allowPlayTask, $issueClassification,$comment,$targetStatus);

        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteTaskIssue(DTO\Request $request, DTO\Response $response) {
        try{
            $params = $request->getParameters()['data'];
            foreach ($params as $param) {
                $id = $param['ID'];
                $this->taskService->removeTaskType($id);
            }
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
        }
    
}
