<?php

namespace Repository;

use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Teknisa\Model\Traits\TQuery;

class AutomaticFraming extends RepositoryBase
{
    use TQuery;

    const ENTITY_NAME = '\Zeedhi\DevOps\Model\Projectmanagement\Entities\AutomaticFraming';
    /**
     * @var EntityManager
     */
    private $entityManager;

    /**
     * TaskTracking constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        parent::__construct(self::ENTITY_NAME);
        $this->entityManager = $entityManager;
    }

    public function getAutomaticFraming($tasks_type) {
		$query =<<<SQL
			select AF.*, TP.LABEL AS TASK_TYPE, TSA.LABEL AS TASK_STATUS_ACTUAL_NAME,  TSD.LABEL AS TASK_STATUS_DESTINY_NAME 
			  FROM AUTOMATIC_FRAMING AF
			  JOIN TASK_TYPE TP ON AF.TASK_TYPE_ID = TP.ID
			  LEFT JOIN TASK_STATUS TSA ON AF.TASK_STATUS_ACTUAL = TSA.ID
			  LEFT JOIN TASK_STATUS TSD ON AF.TASK_STATUS_DESTINY = TSD.ID
			WHERE AF.TASK_TYPE_ID = :TASK_TYPE
SQL;
		
			$params = array(
				'TASK_TYPE'  => $tasks_type
			);
			return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
	}

  public function validateFraming($taskTypeId, $actualStatus, $id) {
      $filter = '';
      if($actualStatus){
        $filter = 'AND AF.TASK_STATUS_ACTUAL = ' . $actualStatus;
      } else{
        $filter = 'AND AF.TASK_STATUS_ACTUAL IS NULL ' ;
      }
      if($id){
        $filter .= ' AND AF.ID <> ' . $id;
      }
      $query = <<<SQL
        SELECT * FROM AUTOMATIC_FRAMING AF
        WHERE AF.TASK_TYPE_ID = :TASK_TYPE  $filter
SQL;
      $params = array(
        'TASK_TYPE'  => $taskTypeId,
        'TASK_STATUS'  => $actualStatus,
        'FRAMING_ID'	=> $id
      );
      return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $query, $params);
  }
}
