import { AlertServiceCustom } from '@/services/AlertServiceCustom';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';
import { InstanceService } from '@/services/InstanceService';
import Messages from '@/services/Messages';
import { Utilities } from '@/services/Utilities';
import {
	DialogService,
	LoadingService,
	Modal,
	ModalService,
} from '@zeedhi/common';
import { Http } from '@zeedhi/core';

export class IssueCommentTypeController {
	public showIssueMainGrid = true;

	private addModal!: Modal;

	public commentTypeName = '';

	public showCommentTypeForm() {
		return !this.showIssueMainGrid;
	}

	public clickBackCardForm() {
		this.showIssueMainGrid = true;
	}

	public async rowClickGridCommentType(params: any) {
		this.commentTypeName = params.row.NAME;
		this.showIssueMainGrid = false;
		const commentTypeFormInstance = InstanceService.getInstanceZdForm('formCommentType');
		commentTypeFormInstance.value = { ...params.row };
	}

	public async openAddCommentTypeModal() {
		if (this.addModal) {
			this.closeAddModal();
		}
		this.addModal = await ModalService.createFromJsonPost('', {
			jsonPath: 'issueConfiguration/modal/addCommentTypeModal',
		});
		this.addModal.show();
	}

	public closeAddModal() {
		this.addModal.hide();
		this.addModal?.destroy();
	}

	public saveAddModal() {
		Utilities.genericAddModalTekGrid(
			'addCommentTypeForm',
			this.addModal,
			'/commentType/save',
			'gridIssueCommentType',
			true,
		);
	}

	public async beforeDeleteGridCommentType(params: any) {
		params.event.preventDefault();
		const buttonYes = [
			{
				name: Utilities.getNameDynamic('yes-'),
				component: 'ZdButton',
				label: 'Sim',
				events: {
					click: () => {
						DialogService.hide();
						this.doDeleteGridCommentType(params);
					},
				},
			},
		];
		DialogServiceCustom.confirmMessage(Messages.DELETE_DEFAULT, buttonYes);
	}

	public async doDeleteGridCommentType(params: any) {
		LoadingService.show();
		try {
			await Http.post('/commentType/remove', {
				data: params.component.selectedRows,
			});
			params.component.selectedRows = [];
			params.component.datasource.get();
		} catch (e) {
			DialogServiceCustom.showErrorBackend(e);
		}
		LoadingService.hide();
	}

	public async saveEditIssue() {
		const formCommentType = InstanceService.getInstanceZdForm('formCommentType');
		if (formCommentType.validate()) {
			const gridCommentType = InstanceService.getInstanceTekGrid(
				'gridIssueCommentType',
			);
			LoadingService.show();
			try {
				await Http.post('/commentType/save', {
					ID: formCommentType.value.ID,
					NAME: formCommentType.value.NAME,
					CONTROL: formCommentType.value.CONTROL,
					ATTACHMENT_REQUIRED:
						formCommentType.value.ATTACHMENT_REQUIRED,
					COMMENT_DESCRIPTION:
						formCommentType.value.COMMENT_DESCRIPTION,
				});
				AlertServiceCustom.defaultSaveSuccessAlert();
				await gridCommentType.datasource.get();
			} catch (e) {
				LoadingService.hide();
				DialogServiceCustom.showErrorBackend(e);
				throw e;
			}
			LoadingService.hide();
		} else {
			DialogServiceCustom.messageErrorValidate();
		}
	}
}
